@@ -17,7 +17,7 @@
 %                                 June 2001                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -354,9 +354,10 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
       /*
         Extract an area from the image.
       */
-      jp2_status=opj_set_decode_area(jp2_codec,jp2_image,image->extract_info.x,
-        image->extract_info.y,image->extract_info.x+(ssize_t) image->columns,
-        image->extract_info.y+(ssize_t) image->rows);
+      jp2_status=opj_set_decode_area(jp2_codec,jp2_image,
+        (OPJ_INT32) image->extract_info.x,(OPJ_INT32) image->extract_info.y,
+        (OPJ_INT32) image->extract_info.x+(ssize_t) image->columns,
+        (OPJ_INT32) image->extract_info.y+(ssize_t) image->rows);
       if (jp2_status == 0)
         {
           opj_stream_destroy(jp2_stream);
@@ -365,16 +366,16 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
           ThrowReaderException(DelegateError,"UnableToDecodeImageFile");
         }
     }
-  if (image_info->number_scenes != 0)
+  if ((image_info->number_scenes != 0) && (image_info->scene != 0))
     jp2_status=opj_get_decoded_tile(jp2_codec,jp2_stream,jp2_image,
-      (unsigned int) image_info->scene);
+      (unsigned int) image_info->scene-1);
   else
-   if (image->ping == MagickFalse)
-     {
-       jp2_status=opj_decode(jp2_codec,jp2_stream,jp2_image);
-       if (jp2_status != 0)
-         jp2_status=opj_end_decompress(jp2_codec,jp2_stream);
-     }
+    if (image->ping == MagickFalse)
+      {
+        jp2_status=opj_decode(jp2_codec,jp2_stream,jp2_image);
+        if (jp2_status != 0)
+          jp2_status=opj_end_decompress(jp2_codec,jp2_stream);
+      }
   if (jp2_status == 0)
     {
       opj_stream_destroy(jp2_stream);
@@ -436,7 +437,7 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
   for (y=0; y < (ssize_t) image->rows; y++)
   {
     register PixelPacket
-      *restrict q;
+      *magick_restrict q;
 
     register ssize_t
       x;
@@ -793,7 +794,7 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
   ssize_t
     y;
 
-  size_t
+  unsigned int
     channels;
 
   /*
@@ -813,7 +814,8 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
   */
   opj_set_default_encoder_parameters(&parameters);
   for (i=1; i < 6; i++)
-    if (((1U << (i+2)) > image->columns) && ((1U << (i+2)) > image->rows))
+    if (((ssize_t) (1 << (i+2)) > image->columns) &&
+        ((ssize_t) (1 << (i+2)) > image->rows))
       break;
   parameters.numresolution=i;
   option=GetImageOption(image_info,"jp2:number-resolutions");
@@ -822,9 +824,9 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
   parameters.tcp_numlayers=1;
   parameters.tcp_rates[0]=0;  /* lossless */
   parameters.cp_disto_alloc=1;
-  if (image->quality != 0)
+  if ((image_info->quality != 0) && (image_info->quality != 100))
     {
-      parameters.tcp_distoratio[0]=(double) image->quality;
+      parameters.tcp_distoratio[0]=(double) image_info->quality;
       parameters.cp_fixed_quality=OPJ_TRUE;
     }
   if (image_info->extract != (char *) NULL)
@@ -924,12 +926,13 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
     }
   else
     {
-      (void) TransformImageColorspace(image,sRGBColorspace);
       if (IsGrayColorspace(image->colorspace) != MagickFalse)
         {
           channels=1;
           jp2_colorspace=OPJ_CLRSPC_GRAY;
         }
+      else
+        (void) TransformImageColorspace(image,sRGBColorspace);
       if (image->matte != MagickFalse)
         channels++;
     }
