@@ -17,7 +17,7 @@
 %                                 July 2009                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -493,7 +493,7 @@ static Image *ReadPESImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if ((count != 4) || (LocaleNCompare((char *) magick,"#PES",4) != 0))
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   count=ReadBlob(image,4,version);
-  offset=(int) ReadBlobLSBLong(image);
+  offset=ReadBlobLSBSignedLong(image);
   if (DiscardBlobBytes(image,offset+36) == MagickFalse)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
@@ -505,12 +505,15 @@ static Image *ReadPESImage(const ImageInfo *image_info,ExceptionInfo *exception)
   number_colors=(size_t) ReadBlobByte(image)+1;
   for (i=0; i < (ssize_t) number_colors; i++)
   {
-    j=(int) ReadBlobByte(image);
+    j=ReadBlobByte(image);
     blocks[i].color=PESColor+(j < 0 ? 0 : j);
     blocks[i].offset=0;
   }
   for ( ; i < 256L; i++)
+  {
     blocks[i].offset=0;
+    blocks[i].color=PESColor;
+  }
   if (DiscardBlobBytes(image,532L-number_colors-21) == MagickFalse)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
@@ -534,8 +537,8 @@ static Image *ReadPESImage(const ImageInfo *image_info,ExceptionInfo *exception)
   delta_y=0;
   while (EOFBlob(image) != EOF)
   {
-    x=(int) ReadBlobByte(image);
-    y=(int) ReadBlobByte(image);
+    x=ReadBlobByte(image);
+    y=ReadBlobByte(image);
     if ((x == 0xff) && (y == 0))
       break;
     if ((x == 254) && (y == 176))
@@ -556,7 +559,7 @@ static Image *ReadPESImage(const ImageInfo *image_info,ExceptionInfo *exception)
           Normal stitch.
         */
         if ((x & 0x40) != 0)
-         x-=0x80;
+          x-=0x80;
       }
     else
       {
