@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -597,8 +597,8 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
         for (i=0; i < (ssize_t) scene; i++)
           for (y=0; y < (ssize_t) image->extract_info.height; y++)
           {
-            pixels=(const unsigned char *) ReadBlobStream(image,length,
-              GetQuantumPixels(quantum_info),&count);
+            (void) ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
+              &count);
             if (count != (ssize_t) length)
               {
                 ThrowFileException(exception,CorruptImageError,
@@ -665,8 +665,8 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
         for (i=0; i < (ssize_t) scene; i++)
           for (y=0; y < (ssize_t) image->extract_info.height; y++)
           {
-            pixels=(const unsigned char *) ReadBlobStream(image,length,
-              GetQuantumPixels(quantum_info),&count);
+            (void) ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
+              &count);
             if (count != (ssize_t) length)
               {
                 ThrowFileException(exception,CorruptImageError,
@@ -733,8 +733,8 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
         for (i=0; i < (ssize_t) scene; i++)
           for (y=0; y < (ssize_t) image->extract_info.height; y++)
           {
-            pixels=(const unsigned char *) ReadBlobStream(image,length,
-              GetQuantumPixels(quantum_info),&count);
+            (void) ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
+              &count);
             if (count != (ssize_t) length)
               {
                 ThrowFileException(exception,CorruptImageError,
@@ -803,7 +803,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
             for (i=0; i < (ssize_t) scene; i++)
               for (y=0; y < (ssize_t) image->extract_info.height; y++)
               {
-                pixels=(const unsigned char *) ReadBlobStream(image,length,
+                (void) ReadBlobStream(image,length,
                   GetQuantumPixels(quantum_info),&count);
                 if (count != (ssize_t) length)
                   {
