@@ -23,7 +23,7 @@
 %                               February 2000                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -112,10 +112,9 @@ MagickExport CacheView *AcquireAuthenticCacheView(const Image *image,
   ExceptionInfo *exception)
 {
   CacheView
-    *restrict cache_view;
+    *magick_restrict cache_view;
 
   cache_view=AcquireVirtualCacheView(image,exception);
-  (void) SyncImagePixelCache(cache_view->image,exception);
   return(cache_view);
 }
 
@@ -155,13 +154,16 @@ MagickExport CacheView *AcquireVirtualCacheView(const Image *image,
   ExceptionInfo *exception)
 {
   CacheView
-    *restrict cache_view;
+    *magick_restrict cache_view;
 
+  magick_unreferenced(image);
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  (void) exception;
+#if defined(MAGICKCORE_OPENCL_SUPPORT)
+  SyncAuthenticOpenCLBuffer(image);
+#endif
   cache_view=(CacheView *) MagickAssumeAligned(AcquireAlignedMemory(1,
     sizeof(*cache_view)));
   if (cache_view == (CacheView *) NULL)
@@ -207,7 +209,7 @@ MagickExport CacheView *AcquireVirtualCacheView(const Image *image,
 MagickExport CacheView *CloneCacheView(const CacheView *cache_view)
 {
   CacheView
-    *restrict clone_view;
+    *magick_restrict clone_view;
 
   assert(cache_view != (CacheView *) NULL);
   assert(cache_view->signature == MagickSignature);
@@ -514,14 +516,14 @@ MagickExport PixelPacket *GetCacheViewAuthenticPixels(CacheView *cache_view,
 %
 */
 MagickExport MagickBooleanType GetOneCacheViewAuthenticPixel(
-  const CacheView *restrict cache_view,const ssize_t x,const ssize_t y,
-  PixelPacket *restrict pixel,ExceptionInfo *exception)
+  const CacheView *magick_restrict cache_view,const ssize_t x,const ssize_t y,
+  PixelPacket *magick_restrict pixel,ExceptionInfo *exception)
 {
   const int
     id = GetOpenMPThreadId();
 
   PixelPacket
-    *restrict pixels;
+    *magick_restrict pixels;
 
   assert(cache_view != (CacheView *) NULL);
   assert(cache_view->signature == MagickSignature);
@@ -766,14 +768,14 @@ MagickExport const PixelPacket *GetCacheViewVirtualPixels(
 %
 */
 MagickExport MagickBooleanType GetOneCacheViewVirtualPixel(
-  const CacheView *restrict cache_view,const ssize_t x,const ssize_t y,
-  PixelPacket *restrict pixel,ExceptionInfo *exception)
+  const CacheView *magick_restrict cache_view,const ssize_t x,const ssize_t y,
+  PixelPacket *magick_restrict pixel,ExceptionInfo *exception)
 {
   const int
     id = GetOpenMPThreadId();
 
   const PixelPacket
-    *restrict pixels;
+    *magick_restrict pixels;
 
   assert(cache_view != (CacheView *) NULL);
   assert(cache_view->signature == MagickSignature);
@@ -832,7 +834,7 @@ MagickExport MagickBooleanType GetOneCacheViewVirtualMethodPixel(
     id = GetOpenMPThreadId();
 
   const PixelPacket
-    *restrict pixels;
+    *magick_restrict pixels;
 
   assert(cache_view != (CacheView *) NULL);
   assert(cache_view->signature == MagickSignature);
@@ -956,7 +958,8 @@ MagickExport MagickBooleanType SetCacheViewStorageClass(CacheView *cache_view,
 %
 */
 MagickExport MagickBooleanType SetCacheViewVirtualPixelMethod(
-  CacheView *restrict cache_view,const VirtualPixelMethod virtual_pixel_method)
+  CacheView *magick_restrict cache_view,
+  const VirtualPixelMethod virtual_pixel_method)
 {
   assert(cache_view != (CacheView *) NULL);
   assert(cache_view->signature == MagickSignature);
@@ -995,7 +998,7 @@ MagickExport MagickBooleanType SetCacheViewVirtualPixelMethod(
 %
 */
 MagickExport MagickBooleanType SyncCacheViewAuthenticPixels(
-  CacheView *restrict cache_view,ExceptionInfo *exception)
+  CacheView *magick_restrict cache_view,ExceptionInfo *exception)
 {
   const int
     id = GetOpenMPThreadId();
