@@ -22,7 +22,7 @@
 %                                January 2013                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -84,6 +84,7 @@
 #define HANDLER_RETURN_TYPE void *
 #define HANDLER_RETURN_VALUE (void *) NULL
 #define SOCKET_TYPE int
+#define LENGTH_TYPE size_t
 #define MAGICKCORE_HAVE_DISTRIBUTE_CACHE
 #elif defined(MAGICKCORE_WINDOWS_SUPPORT)
 #define CHAR_TYPE_CAST (char *)
@@ -91,12 +92,18 @@
 #define HANDLER_RETURN_TYPE DWORD WINAPI
 #define HANDLER_RETURN_VALUE 0
 #define SOCKET_TYPE SOCKET
+#define LENGTH_TYPE int
 #define MAGICKCORE_HAVE_DISTRIBUTE_CACHE
 #else
+#ifdef __VMS
+#define CLOSE_SOCKET(socket) (void) close(socket)
+#else
 #define CLOSE_SOCKET(socket) 
+#endif
 #define HANDLER_RETURN_TYPE  void *
 #define HANDLER_RETURN_VALUE  (void *) NULL
 #define SOCKET_TYPE  int
+#define LENGTH_TYPE size_t
 #undef send
 #undef recv
 #define send(file,buffer,length,flags)  0
@@ -138,7 +145,7 @@
 */
 
 static inline MagickOffsetType dpc_read(int file,const MagickSizeType length,
-  unsigned char *restrict message)
+  unsigned char *magick_restrict message)
 {
   register MagickOffsetType
     i;
@@ -154,7 +161,7 @@ static inline MagickOffsetType dpc_read(int file,const MagickSizeType length,
   count=0;
   for (i=0; i < (MagickOffsetType) length; i+=count)
   {
-    count=recv(file,CHAR_TYPE_CAST message+i,(size_t) MagickMin(length-i,
+    count=recv(file,CHAR_TYPE_CAST message+i,(LENGTH_TYPE) MagickMin(length-i,
       (MagickSizeType) SSIZE_MAX),0);
     if (count <= 0)
       {
@@ -173,7 +180,7 @@ static int ConnectPixelCacheServer(const char *hostname,const int port,
   char
     service[MaxTextExtent];
 
-  const char
+  char
     *shared_secret;
 
   int
@@ -197,12 +204,14 @@ static int ConnectPixelCacheServer(const char *hostname,const int port,
   */
   *session_key=0;
   shared_secret=GetPolicyValue("shared-secret");
-  if (shared_secret == (const char *) NULL)
+  if (shared_secret == (char *) NULL)
     {
+      shared_secret=DestroyString(shared_secret);
       (void) ThrowMagickException(exception,GetMagickModule(),CacheError,
         "DistributedPixelCache","'%s'","shared secret expected");
       return(-1);
     }
+  shared_secret=DestroyString(shared_secret);
 #if defined(MAGICKCORE_WINDOWS_SUPPORT)
   NTInitializeWinsock(MagickTrue);
 #endif
@@ -227,7 +236,7 @@ static int ConnectPixelCacheServer(const char *hostname,const int port,
         "DistributedPixelCache","'%s'",hostname);
       return(-1);
     }
-  status=connect(client_socket,result->ai_addr,result->ai_addrlen);
+  status=connect(client_socket,result->ai_addr,(socklen_t) result->ai_addrlen);
   if (status == -1)
     {
       CLOSE_SOCKET(client_socket);
@@ -429,7 +438,7 @@ static MagickBooleanType DestroyDistributeCache(SplayTreeInfo *registry,
 }
 
 static inline MagickOffsetType dpc_send(int file,const MagickSizeType length,
-  const unsigned char *restrict message)
+  const unsigned char *magick_restrict message)
 {
   MagickOffsetType
     count;
@@ -448,8 +457,8 @@ static inline MagickOffsetType dpc_send(int file,const MagickSizeType length,
   count=0;
   for (i=0; i < (MagickOffsetType) length; i+=count)
   {
-    count=(MagickOffsetType) send(file,CHAR_TYPE_CAST message+i,(size_t) MagickMin(length-i,
-      (MagickSizeType) SSIZE_MAX),MSG_NOSIGNAL);
+    count=(MagickOffsetType) send(file,CHAR_TYPE_CAST message+i,(LENGTH_TYPE)
+      MagickMin(length-i,(MagickSizeType) SSIZE_MAX),MSG_NOSIGNAL);
     if (count <= 0)
       {
         count=0;
@@ -751,7 +760,7 @@ static MagickBooleanType WriteDistributeCachePixels(SplayTreeInfo *registry,
 
 static HANDLER_RETURN_TYPE DistributePixelCacheClient(void *socket)
 {
-  const char
+  char
     *shared_secret;
 
   ExceptionInfo
@@ -790,11 +799,12 @@ static HANDLER_RETURN_TYPE DistributePixelCacheClient(void *socket)
     Distributed pixel cache client.
   */
   shared_secret=GetPolicyValue("shared-secret");
-  if (shared_secret == (const char *) NULL)
+  if (shared_secret == (char *) NULL)
     ThrowFatalException(CacheFatalError,"shared secret expected");
   p=session;
   (void) CopyMagickString((char *) p,shared_secret,MaxTextExtent);
   p+=strlen(shared_secret);
+  shared_secret=DestroyString(shared_secret);
   random_info=AcquireRandomInfo();
   secret=GetRandomKey(random_info,DPCSessionKeyLength);
   (void) memcpy(p,GetStringInfoDatum(secret),DPCSessionKeyLength);
@@ -936,7 +946,7 @@ MagickExport void DistributePixelCacheServer(const int port,
         CLOSE_SOCKET(server_socket);
         continue;
       }
-    status=bind(server_socket,p->ai_addr,p->ai_addrlen);
+    status=bind(server_socket,p->ai_addr,(socklen_t) p->ai_addrlen);
     if (status == -1)
       {
         CLOSE_SOCKET(server_socket);
@@ -1106,7 +1116,11 @@ MagickPrivate MagickBooleanType OpenDistributePixelCache(
   DistributeCacheInfo *server_info,Image *image)
 {
   MagickBooleanType
+#ifdef __VMS
+     status=MagickTrue;
+#else
     status;
+#endif
 
   MagickOffsetType
     count;
@@ -1244,7 +1258,7 @@ MagickPrivate MagickOffsetType ReadDistributePixelCacheIndexes(
 %
 %      MagickOffsetType ReadDistributePixelCachePixels(
 %        DistributeCacheInfo *server_info,const RectangleInfo *region,
-%        const MagickSizeType length,unsigned char *restrict pixels)
+%        const MagickSizeType length,unsigned char *magick_restrict pixels)
 %
 %  A description of each parameter follows:
 %
@@ -1261,7 +1275,7 @@ MagickPrivate MagickOffsetType ReadDistributePixelCacheIndexes(
 */
 MagickPrivate MagickOffsetType ReadDistributePixelCachePixels(
   DistributeCacheInfo *server_info,const RectangleInfo *region,
-  const MagickSizeType length,unsigned char *restrict pixels)
+  const MagickSizeType length,unsigned char *magick_restrict pixels)
 {
   MagickOffsetType
     count;
@@ -1329,7 +1343,11 @@ MagickPrivate MagickBooleanType RelinquishDistributePixelCache(
   DistributeCacheInfo *server_info)
 {
   MagickBooleanType
+#ifdef __VMS
+     status = MagickTrue;
+#else
     status;
+#endif
 
   MagickOffsetType
     count;
@@ -1451,7 +1469,8 @@ MagickPrivate MagickOffsetType WriteDistributePixelCacheIndexes(
 %
 %      MagickBooleanType WriteDistributePixelCachePixels(
 %        DistributeCacheInfo *server_info,const RectangleInfo *region,
-%        const MagickSizeType length,const unsigned char *restrict pixels)
+%        const MagickSizeType length,
+%        const unsigned char *magick_restrict pixels)
 %
 %  A description of each parameter follows:
 %
@@ -1468,7 +1487,7 @@ MagickPrivate MagickOffsetType WriteDistributePixelCacheIndexes(
 */
 MagickPrivate MagickOffsetType WriteDistributePixelCachePixels(
   DistributeCacheInfo *server_info,const RectangleInfo *region,
-  const MagickSizeType length,const unsigned char *restrict pixels)
+  const MagickSizeType length,const unsigned char *magick_restrict pixels)
 {
   MagickOffsetType
     count;
