@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
   You may not use this file except in compliance with the License.
@@ -15,8 +15,8 @@
 
   MagickCore Windows NT private methods.
 */
-#ifndef _MAGICKCORE_NT_BASE_PRIVATE_H
-#define _MAGICKCORE_NT_BASE_PRIVATE_H
+#ifndef MAGICKCORE_NT_BASE_PRIVATE_H
+#define MAGICKCORE_NT_BASE_PRIVATE_H
 
 #include "magick/delegate.h"
 #include "magick/delegate-private.h"
@@ -168,4 +168,4 @@ extern MagickPrivate void
 }
 #endif /* !C++ */
 
-#endif /* !_MAGICKCORE_NT_BASE_H */
+#endif /* !MAGICKCORE_NT_BASE_H */
